@@ -12,12 +12,27 @@ ACCT_DET_ENDPOINT = "auth/account-details"
 GW_STATUS_ENDPOINT = "gw/gateways/status"
 GW_USAGE_ENDPOINT = "smartmeter/usageByHour"
 
+DEFAULT_TIMEOUT = 10  # seconds
+
 MQTT_HOST = "app-core1.de-iot.io"
 MQTT_PORT = 443
 MQTT_ENDPOINT = "/app-mqtt"
 MQTT_KEEPALIVE = 50  # Seconds, it appears the server will disconnect after 60s idle
-FASTPOLL_TIMEOUT = 900 - 3  # seconds
-FASTPOLL_RETRY = 60  # if no messages after this time, retry fastpoll request
-FASTPOLL_RETRY_COUNT = 3
 
-DEFAULT_TIMEOUT = 10  # seconds
+# in seconds, how long to until the fastpoll request has timed out and a new one needs to be made
+FASTPOLL_TIMEOUT_SEC = 900 - 3  # seconds
+
+# in seconds, how long to wait for a message before retrying fastpoll or reconnecting
+MESSAGE_TIMEOUT_SEC = 60
+
+# number of times a message timeout can occur before just reconnecting
+MESSAGE_TIMEOUT_RETRY_COUNT = 3
+
+# in minutes, minimum amount of time to wait before retrying connection on forever loop
+FOREVER_RETRY_MIN_MINUTES = 1
+
+# in minutes, maximum amount of time to wait before trying connection on forever loop
+FOREVER_RETRY_MAX_MINUTES = 60
+
+# in seconds, how long to wait for a connection before timing out
+CONNECT_TIMEOUT_SEC = 60
